@@ -1,4 +1,4 @@
-import { FhirWorker } from '@tamanu/shared/tasks';
+import { FhirQueueManager } from '@tamanu/shared/tasks';
 import { JOB_TOPICS } from '@tamanu/constants';
 import { log } from '@tamanu/shared/services/logging';
 
@@ -8,12 +8,12 @@ import { fromUpstream } from './refresh/fromUpstream';
 import { resolver } from './resolver';
 
 export async function startFhirWorkerTasks({ store, topics }) {
-  const worker = new FhirWorker(store, log);
-  await worker.start();
+  const queueManager = new FhirQueueManager(store, log);
+  await queueManager.start();
 
   const setHandler = async (topic, handler) => {
     if (!topics || topics.includes(topic)) {
-      await worker.setHandler(topic, handler);
+      await queueManager.setHandler(topic, handler);
     }
   };
 
@@ -22,6 +22,8 @@ export async function startFhirWorkerTasks({ store, topics }) {
   await setHandler(JOB_TOPICS.FHIR.REFRESH.FROM_UPSTREAM, fromUpstream);
   await setHandler(JOB_TOPICS.FHIR.RESOLVER, resolver);
 
-  worker.processQueueNow();
-  return worker;
+  for (const topic of topics) {
+    queueManager.processQueueNow(topic);
+  }
+  return queueManager;
 }
