@@ -185,11 +185,6 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: true,
         },
-        enableCovidClearanceCertificate: {
-          description: 'Enable COVID certificate printout',
-          type: yup.boolean(),
-          defaultValue: false,
-        },
         editPatientDisplayId: {
           description: 'Allow the editing of an existing patients display id',
           type: yup.boolean(),
@@ -370,13 +365,29 @@ export const globalSettings = {
           description: 'Lab request settings',
           properties: {
             enableLabResultsPrintout: {
-              name: "Lab results printout",
-              description: 'Enable lab results printout (print results button and interim report option)',
+              name: 'Lab results printout',
+              description:
+                'Enable lab results printout (print results button and interim report option)',
               type: yup.boolean(),
               defaultValue: true,
             },
           },
         },
+        covidCertificates: {
+          description: 'COVID certificate settings',
+          properties: {
+            enableCovidClearanceCertificate: {
+              description: 'Enable COVID certificate printout',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+            enableCovidVaccinationCertificateSigning: {
+              description: 'Enable signing of COVID vaccination certificate',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+          },
+        },
       },
     },
     customisations: {
@@ -1363,14 +1374,33 @@ export const globalSettings = {
         appointmentConfirmation: {
           description: 'The email sent to confirm an appointment',
           properties: {
-            subject: {
-              type: yup.string().trim().min(1),
-              defaultValue: 'Appointment confirmation',
+            locationBooking: {
+              description: 'The email template sent to confirm a location booking',
+              properties: {
+                subject: {
+                  type: yup.string().trim().min(1),
+                  defaultValue: 'Booking confirmation',
+                },
+                body: {
+                  type: yup.string().trim().min(1),
+                  defaultValue:
+                    'Hi $firstName$ $lastName$,\n\nThis is a confirmation that your booking has been scheduled at $facilityName$.\nDate: $startDate$\nTime: $startTime$\nLocation: $locationName$, $facilityName$$clinicianName$\n\nDo not respond to this email.',
+                },
+              },
             },
-            body: {
-              type: yup.string().trim().min(1),
-              defaultValue:
-                'Hi $firstName$ $lastName$,\n\n This is a confirmation that your appointment has been scheduled at $facilityName$.\nDate: $startDate$\nTime: $startTime$\nLocation: $locationName$, $facilityName$$clinicianName$\n\nDo not respond to this email.',
+            outpatientAppointment: {
+              description: 'The email template sent to confirm an outpatient appointment',
+              properties: {
+                subject: {
+                  type: yup.string().trim().min(1),
+                  defaultValue: 'Appointment confirmation',
+                },
+                body: {
+                  type: yup.string().trim().min(1),
+                  defaultValue:
+                    'Hi $firstName$ $lastName$,\n\nThis is a confirmation that your appointment has been scheduled at $facilityName$.\nDate: $startDate$\nTime: $startTime$\nLocation: $locationName$, $facilityName$$clinicianName$\n\nDo not respond to this email.',
+                },
+              },
             },
           },
         },
